Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(878)

Unified Diff: third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js

Issue 2888263002: DevTools: Roll Lighthouse binary to 2.0.1-alpha.0 (Closed)
Patch Set: rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js
diff --git a/third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js b/third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js
index 3d054a4ed142dc18e4336ab27f32a7f08f92118f..1ea401d3a995bff8c9858fbd7238866dfef81536 100644
--- a/third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js
+++ b/third_party/WebKit/Source/devtools/front_end/audits2/lighthouse/renderer/details-renderer.js
@@ -15,7 +15,7 @@
*/
'use strict';
/* globals self CriticalRequestChainRenderer */
class DetailsRenderer {
/**
@@ -218,7 +218,7 @@ class DetailsRenderer {
let timing = thumbnail.timing.toLocaleString() + ' ms';
if (thumbnail.timing > 1000) {
- timing = Math.round(thumbnail.timing / 100) / 10 + ' s';
+ timing = Util.formatNumber(thumbnail.timing / 1000) + ' s';
}
const timingEl = this._dom.createChildOf(frameEl, 'div', 'lh-filmstrip__timestamp');
@@ -326,6 +326,7 @@ DetailsRenderer.ThumbnailDetails; // eslint-disable-line no-unused-expressions
/** @typedef {{
* type: string,
+ * scale: number,
* items: !Array<{timing: number, timestamp: number, data: string}>,
* }}
*/
@@ -15,7 +15,7 @@
*/
'use strict';
-/* globals self CriticalRequestChainRenderer */
+/* globals self CriticalRequestChainRenderer Util */
class DetailsRenderer {
/**

Powered by Google App Engine
This is Rietveld 408576698